@@ -36,6 +36,10 @@ test_that("list_import_jobs", {
   expect_error(svc$list_import_jobs(), NA)
 })
 
+test_that("list_multi_region_endpoints", {
+  expect_error(svc$list_multi_region_endpoints(), NA)
+})
+
 test_that("list_recommendations", {
   expect_error(svc$list_recommendations(), NA)
 })
